pycocoa.runtime.ObjCBoundMethod

Package pycocoa :: Module runtime :: Class ObjCBoundMethod |
[frames] | no frames]

# Class ObjCBoundMethod

              object --+
                       |
    internals._Objectype --+
                           |
                   _ObjCBase --+
                               |
                              ObjCBoundMethod

Known Subclasses:
  - ObjCBoundClassMethod

Python wrapper for a bound ObjC instance method, an IMP_t.

Note: Each ObjC method invocation requires creation of another, new `ObjCBound[Class]Method` instance which is discarded immediately thereafter.

Instance Methods
__init__(self, method, objc_id, inst) Initialize with an ObjC instance or class method. |
__str__(self) str(x) |
__call__(self, *args) Call the method with the given arguments. |
Inherited from `_ObjCBase`: `__repr__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| inst Get the `ObjCInstance` or `ObjCClass`.
| method Get the method (`ObjC[Class]Method`).
| name Get the method's name (`str`).
| objc_id Get the ObjC instance (`Class_t` or ObjCSubclass).
Inherited from `_ObjCBase`: `description` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`

Method Details

### __init__(self, method, objc_id, inst) (Constructor) |
Initialize with an ObjC instance or class method. Parameters: `method` - The ObjC method (`ObjC[Class]Method`). `objc_id` - The ObjC instance (ObjCInstance) or class (`Class_t`). `inst` - The instance `ObjCInstance` or `ObjCClass`, used only to report invokation errors. Overrides: object.__init__

### __str__(self) (Informal representation operator) |
str(x) Overrides: object.__str__ (inherited documentation)

Property Details

### inst Get the `ObjCInstance` or `ObjCClass`. Get Method: inst(self) - Get the `ObjCInstance` or `ObjCClass`. Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### method Get the method (`ObjC[Class]Method`). Get Method: method(self) - Get the method (`ObjC[Class]Method`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### name Get the method's name (`str`). Get Method: name(self) - Get the method's name (`str`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### objc_id Get the ObjC instance (`Class_t` or ObjCSubclass). Get Method: objc_id(self) - Get the ObjC instance (`Class_t` or ObjCSubclass). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.